<?php

namespace API\script\Gateway;

use API\script\Config\Connection;
use PDO;

/**
 * Permet d'accéder, d'écrire ou de modifier les données contenues dans la table PossibleResponse.
 */
class GatewayPossibleResponse
{
    /**
     * @var Connection
     */
    private Connection $connection;

    /**
     *
     */
    public function __construct()
    {
        $this->connection = connect();
    }

    /**
     * Permet de récupérer les différentes réponses possibles à une question donnée.
     *
     * @param string $idQuestion Id de la question pour laquelle on veut récupérer les réponses possibles
     *
     * @return array Retourne la liste de possibles réponses
     */
    public function getPossibleResponseByQuestion(string $idQuestion): array
    {
        $query = "SELECT pr.* FROM Propose p, PossibleResponse pr
                        WHERE p.question = :questionId AND p.possibleResponse = pr.id";
        $this->connection->executeQuery($query, array(
            ':questionId' => array($idQuestion, PDO::PARAM_INT)
        ));

        return $this->connection->getResults();
    }

    /**
     * Permet d'insérer une possible réponse dans la base de donnée.
     *
     * @param string $contentPossibleResponse Contenu de la possible réponse
     * @return int
     */
    public function insertPossibleResponse(string $contentPossibleResponse): int
    {
        $query = "INSERT INTO PossibleResponse(content) VALUES(:content)";
        $this->connection->executeQuery($query, array(
            ':content' => array($contentPossibleResponse, PDO::PARAM_STR)
        ));

        return $this->connection->lastInsertId();
    }

    /**
     * Permet de supprimer une possible réponse de la base de donnée par son id.
     *
     * @param int $id Id de la possible réponse à supprimer
     *
     * @return void
     */
    public function deletePossibleResponse(int $id): void
    {
        $query = "DELETE FROM Reference WHERE response = :id";
        $this->connection->executeQuery($query, array(
            ':id' => array($id, PDO::PARAM_INT)
        ));

        $query = "DELETE FROM PossibleResponse WHERE id = :id";
        $this->connection->executeQuery($query, array(
            ':id' => array($id, PDO::PARAM_INT)
        ));
    }
}
