<?php

namespace Config\DataManagement;

class Clean
{
    /**
     * Cette fonction prend une chaîne de caractères en entrée et retourne une version nettoyée de cette chaîne.
     * Elle supprime les espaces de début et de fin, ainsi que toutes les balises HTML, et encode les
     * caractères spéciaux.
     *
     * @param string $string La chaîne à nettoyer
     * @return string La chaîne nettoyée
     */

    public static function simpleString(string $string): string
    {
        $string = trim($string);
        $string = strip_tags($string);
        return htmlspecialchars($string);
    }

    /**
     * Cette fonction prend une chaîne de caractères en entrée et retourne une version nettoyée de cette chaîne.
     * Elle supprime les espaces de début et de fin, ainsi que toutes les balises HTML, et encode les
     * caractères spéciaux.
     * @param $email
     * @return string La chaîne nettoyée
     */

    public static function email($email): string
    {
        $email = self::simpleString($email);
        return filter_var($email, FILTER_SANITIZE_EMAIL);
    }

    /**
     * Cette fonction prend un nombre entier en entrée, nettoie et retourne une version formatée de l'entier.
     * Elle  applique la fonction filter_var avec le filtre FILTER_SANITIZE_NUMBER_INT.
     * @param int $int Le nombre entier à nettoyer et formater
     * @return int Le nombre entier formaté
     */

    public static function int(int $int): int
    {
        return filter_var($int, FILTER_SANITIZE_NUMBER_INT);
    }
}
